@@ -357,7 +357,8 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
   start.month <- startMonth(mydata$date)
   end.month <- endMonth(mydata$date)
 
-  mydata <- timeAverage(mydata,
+  mydata <- suppressWarnings(
+    timeAverage(mydata,
     type = type,
     avg.time = avg.time,
     statistic = statistic,
@@ -365,6 +366,7 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
     data.thresh = data.thresh,
     interval = interval
   )
+  )
 
   # timeAverage drops type if default
   if ("default" %in% type) mydata$default <- "default"
